
# $Id: Serializer.pm,v 1.2 2008/12/07 03:28:45 Martin Exp $

package RDF::Simple::Serializer;

use strict;
use warnings;

use base q(RDF::Simple::Serialiser);

=head1 NAME

RDF::Simple::Serializer - a synonym for RDF::Simple::Serialiser

=head1 SYNOPSIS

Same as RDF::Simple::Serialiser

=head1 DESCRIPTION

See RDF::Simple::Serialiser

=cut

1;

__END__
